@@ -1,5 +1,5 @@
 seg.def.fit.boot<-function(obj, Z, PSI, mfExt, opz, n.boot=10, size.boot=NULL, jt=FALSE,
-    nonParam=TRUE, random=FALSE){
+    nonParam=TRUE, random=FALSE, break.boot=n.boot){
 #random se TRUE prende valori random quando e' errore: comunque devi modificare qualcosa (magari con it.max)
 #     per fare restituire la dev in corrispondenza del punto psi-random
 #nonParm. se TRUE implemneta il case resampling. Quello semiparam dipende dal non-errore di
@@ -59,6 +59,12 @@ extract.psi<-function(lista){
 #      if(visualBoot) cat(0, " ", formatC(opz$dev0, 3, format = "f"),"", "(No breakpoint(s))", "\n")
       count.random<-0
       for(k in seq(n.boot)){
+        n.boot.rev<-4
+        if(length(na.omit(diff(all.selected.ss[1:n.boot.rev])))==(n.boot.rev-1) && all(round(diff(all.selected.ss[1:n.boot.rev]),6)==0)){
+          qpsi<-sapply(1:ncol(Z),function(i)mean(est.psi0[i]>=Z[,i]))
+          est.psi0<-sapply(1:ncol(Z),function(i)quantile(Z[,i],probs=1-qpsi[i],names=FALSE))
+        }
+        
           PSI <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
           if(jt) Z<-apply(Z.orig,2,jitter)
           if(nonParam){
@@ -104,6 +110,11 @@ extract.psi<-function(lista){
                         "  est.psi = ",paste(formatC(unlist(est.psi0),digits=3,format="f"), collapse="  "), #sprintf('%.2f',x)
                         sep=""), "\n")
             }
+            asss<-na.omit(all.selected.ss)
+            if(length(asss)>break.boot){
+              if(all(rev(round(diff(asss),6))[1:(break.boot-1)]==0)) break
+            }
+            
           } #end n.boot
 
       
@@ -118,5 +129,6 @@ extract.psi<-function(lista){
       }
       if(!is.list(o0)) return(0)
       o0$boot.restart<-ris
+      rm(.Random.seed, envir=globalenv())
       return(o0)
       }
\ No newline at end of file
